const csvUrl = 'https://gist.githubusercontent.com/happymail6/0c2060c649af8333cef751f2ad4c1ba5/raw/14a3c70dc4c33150b505b0812471aea3acf4b974/MarvelVsDC.csv';
      const xValue = d => d.Rate;
      const xLabel = 'IMDB Rate';
      const yValue = d => d.Budget/10000000;
      const yLabel = 'Budget (in B)';
      const colorValue = d => d.Company;
      const colorLabel = 'Company';
      const margin = { left: 100, right: 150, top: 10, bottom: 120 };

      const svg = d3.select('svg');
      const width = svg.attr('width');
      const height = svg.attr('height');
      const innerWidth = width - margin.left - margin.right;
      const innerHeight = height - margin.top - margin.bottom;

     const g = svg
        .append('g')
          .attr('transform', `translate(${margin.left},${margin.top})`);
      const xAxisG = g
        .append('g')
          .attr('transform', `translate(0, ${innerHeight})`);
      const yAxisG = g.append('g');
      const colorLegendG = g
        .append('g')
          .attr('transform', `translate(${innerWidth + 60}, 150)`);

      xAxisG
        .append('text')
          .attr('class', 'axis-label')
          .attr('x', innerWidth / 2)
          .attr('y', 80)
          .text(xLabel);

      yAxisG
        .append('text')
          .attr('class', 'axis-label')
          .attr('x', -innerHeight / 2)
          .attr('y', -60)
          .attr('transform', `rotate(-90)`)
          .style('text-anchor', 'middle')
          .text(yLabel);

      colorLegendG
        .append('text')
          .attr('class', 'legend-label')
          .attr('x', -30)
          .attr('y', -40)
          .text(colorLabel);


      const xScale = d3.scaleLinear();
      const yScale = d3.scaleLinear();
      const colorScale = d3.scaleOrdinal().range(d3.schemeCategory10);

      const xAxis = d3
        .axisBottom()
        .scale(xScale)
        .tickPadding(15)
        .tickSize(-innerHeight);

      const yAxis = d3
        .axisLeft()
        .scale(yScale)
        .ticks(5)
        .tickPadding(15)
        .tickSize(-innerWidth);

      const colorLegend = d3
        .legendColor()
        .scale(colorScale)
        .shape('circle');

      const row = d => {
        d.Budget = +d.Budget;
        d.Rate = +d.Rate;

        return d;
      };

      d3.csv(csvUrl, row).then(data => {
        xScale
          .domain(d3.extent(data, xValue))
          .range([0, innerWidth])
          .nice();

        yScale
          .domain(d3.extent(data, yValue))
          .range([innerHeight, 0])
          .nice();

        g.selectAll('circle')
          .data(data)
          .enter()
          .append('circle')
            .attr('cx', d => xScale(xValue(d)))
            .attr('cy', d => yScale(yValue(d)))
            .attr('fill', d => colorScale(colorValue(d)))
            .attr('fill-opacity', 2)
            .attr('r', 4);

        xAxisG.call(xAxis);
        yAxisG.call(yAxis);
        colorLegendG
            .call(colorLegend)
          .selectAll('.cell text')
            .attr('dy', '0.3em');
      });
    